# meine_funktionen.py
#
# Sammlung nützlicher Funktionen
#
# Version: 00.00.01
# Datum: 17.01.2024
# Autor: Peter Stöck
#
# Nach Ideen von:
# Andreas Günther,
#


from machine import Pin
from time import sleep_ms

####################################################################
# Tastenfunktionen
####################################################################

#
# Taster init
#
b_up = Pin(11, Pin.IN, Pin.PULL_DOWN)
b_down = Pin(14, Pin.IN, Pin.PULL_DOWN)
b_left = Pin(12, Pin.IN, Pin.PULL_DOWN)
b_right = Pin(13, Pin.IN, Pin.PULL_DOWN)
b_ok = Pin(15, Pin.IN, Pin.PULL_DOWN)

# Die Pins für das Demoboard
MPDB_BUTTONS = (b_up, b_down, b_left, b_right, b_ok)

# get_button(buttons)
# buttons muss iterierbar sein!
# wartet auf einen Tastendruck
# und gibt den Namen der Taste zurück.

def get_button(buttons):
    while True:
        for i in buttons:
            if i.value():
                sleep_ms(30)
                if i.value():          
                    while i.value():
                        pass            
                    return i

# Anwendung:
# import meine_funktionen as mf
# mf.get_button(buttons)
#
# get_b = mf.get_button
# get_b()
#

# ----------------------------------------------------------------------

# button_pressed(buttons)
# Prüft ob eine Taste gedrückt ist.
# liefert
# tasten_pins muss iterierbar sein!

def button_pressed(buttons):
    pressed = False
    for b in buttons:
        if b.value():
            pressed = True
    return pressed

# ----------------------------------------------------------------------

# get_button_2(buttons)
# wartet bis alle Tasten losgelassen sind
# und wartet dann auf einen Tastendrück.
# kehrt zurück, sobald ein Tastendruck
# erkannt wurde.

def get_button_2(buttons):
    pressed = True
    while pressed:
        pressed = False 
        for b in buttons:
            if b.value():
                pressed = True 
    sleep_ms(30)               # Prellen abwarten
    while True:
        for i in buttons:
            if i.value():
                sleep_ms(30)
                if i.value():             
                    return i

####################################################################
# Datum- und Zeitfunktionen
####################################################################

def get_date():
    import time
    date_time = time.localtime()
    return '-'.join((str(date_time[2]), str(date_time[1]), str(date_time[0])))


def get_time():
    import time
    date_time = time.localtime()
    return ':'.join((str(date_time[3]), str(date_time[4]), str(date_time[5])))

